<template>
    <div class="side-box map-background" v-show="location">
        <el-tabs v-model="activeName" @tab-click="handleClick">
            <el-tab-pane label="点击定位" name="first">
                <div class="click-location">
                    <el-input v-model="clickLocation"></el-input>
                    <el-button type="primary" @click="confirm">确认</el-button>
                </div>
            </el-tab-pane>
            <el-tab-pane label="管段定位" name="second">
                <div class="place">
                    <div class="place-top">
                        <div class="place-left">
                            <el-form :model="linePos" label-width="90px">
                                <el-form-item label="管线名称:">
                                    <el-input v-model="linePos.lineName"></el-input>
                                </el-form-item>
                                <el-form-item label="附属设施:">
                                    <el-select v-model="linePos.affFac">
                                        <el-option
                                                v-for="item in linePos.affFacList"
                                                :key="item.value"
                                                :label="item.label"
                                                :value="item.value">
                                        </el-option>
                                    </el-select>
                                </el-form-item>
                            </el-form>
                        </div>
                        <div class="place-right">
                            <el-button type="primary" size="small" @click="fileChoose">搜索</el-button>
                        </div>
                    </div>
                    <div class="place-bottom">
                        <el-button type="primary" @click="confirm">确认</el-button>
                    </div>
                </div>
            </el-tab-pane>
            <el-tab-pane label="经纬度定位" name="third">
                <div class="place">
                    <div class="place-top">
                        <div class="place-left">
                            <el-form :model="LongLatPos" label-width="90px">
                                <el-form-item label="经度:">
                                    <el-input v-model="LongLatPos.longPos"></el-input>
                                </el-form-item>
                                <el-form-item label="纬度:">
                                    <el-input v-model="LongLatPos.latPos"></el-input>
                                </el-form-item>
                            </el-form>
                        </div>
                        <div class="place-right">
                            <el-button type="primary" size="small">搜索</el-button>
                        </div>
                    </div>
                    <div class="place-bottom">
                        <el-button type="primary" @click="confirm">确认</el-button>
                    </div>
                </div>
            </el-tab-pane>
        </el-tabs>
    </div>
</template>

<script>
import eventBus from '../../../eventBus'

export default {
  name: 'PositionChange',
  props: ['location'],
  data () {
    return {
      pipelineFile: false,
      activeName: 'first',
      clickLocation: '',
      // 经纬度定位
      LongLatPos: {
        longPos: '',
        latPos: ''
      },
      // 管段定位
      linePos: {
        lineName: '',
        affFac: '',
        affFacList: [
          {
            label: '阀门A',
            value: '1'
          },
          {
            label: '阀门B',
            value: '2'
          }
        ]
      },
      fileChoChange: false
    }
  },
  mounted () {
    // 接收规定 每次重新选择定位 都指定 选择第一个开始
    eventBus.$on('tab-change', (obj) => {
      this.activeName = obj
    })
  },
  methods: {
    // tab 切换用于判断
    handleClick (tab) {},
    // 点击文件选择 显示第三级页面 进行管线/段选择
    fileChoose () {
      this.fileChoChange = !this.fileChoChange
      eventBus.$emit('pipelineFile-choose', this.fileChoChange)
    },
    // 点击确认按钮事件
    confirm () {
      // 子组件通过事件 传递数据 控制自身显示隐藏
      this.$emit('localCation', false)
      // 通过bus 控制三级附属弹框的隐藏
      eventBus.$emit('pipelineFile-choose', false)
    }
  }
}
</script>

<style lang="less" scoped>

    .side-box {
        min-width: 1.94532rem;
        max-width: 1.94532rem;
    }

    .click-location {
        margin: 0 auto;
        text-align: center;

        .el-input {
            width: 90%;
            margin: 15px auto;
        }

        .el-button {
            margin: 15px auto;
        }
    }

    .place {
        text-align: center;

        .place-top {
            display: flex;
            align-items: center;
            justify-content: space-around;

            .place-right {
                .el-button {
                    margin: 15px;
                }
            }
        }

        .place-bottom {
            .el-button {
                margin: 15px;
            }
        }
    }
</style>
